@@ -24,8 +24,11 @@ class TestGeometryConvert(TestBase):
         self.spark.sql("SELECT st_GeomFromWKT('Point(21.0 52.0)')").show()
 
     def test_spark_config(self):
-        kryo_reg = ('spark.kryo.registrator', 'org.apache.sedona.core.serde.SedonaKryoRegistrator')
-        serializer = ('spark.serializer', 'org.apache.spark.serializer.KryoSerializer')
+        kryo_reg = (
+            "spark.kryo.registrator",
+            "org.apache.sedona.core.serde.SedonaKryoRegistrator",
+        )
+        serializer = ("spark.serializer", "org.apache.spark.serializer.KryoSerializer")
         spark_config = self.spark.sparkContext._conf.getAll()
         assert kryo_reg in spark_config
         assert serializer in spark_config
