@@ -15,41 +15,45 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from sedona.core.SpatialRDD import PointRDD, CircleRDD
-from tests.properties.point_properties import input_location, offset, splitter, num_partitions
+from tests.properties.point_properties import (
+    input_location,
+    num_partitions,
+    offset,
+    splitter,
+)
 from tests.test_base import TestBase
 
+from sedona.core.SpatialRDD import CircleRDD, PointRDD
+
 
 class TestSpatialRddAssignment(TestBase):
 
     def test_raw_spatial_rdd_assignment(self):
         spatial_rdd = PointRDD(
-            self.sc,
-            input_location,
-            offset,
-            splitter,
-            True,
-            num_partitions
+            self.sc, input_location, offset, splitter, True, num_partitions
         )
         spatial_rdd.analyze()
 
         empty_point_rdd = PointRDD()
         empty_point_rdd.rawSpatialRDD = spatial_rdd.rawSpatialRDD
         empty_point_rdd.analyze()
-        assert empty_point_rdd.countWithoutDuplicates() == spatial_rdd.countWithoutDuplicates()
+        assert (
+            empty_point_rdd.countWithoutDuplicates()
+            == spatial_rdd.countWithoutDuplicates()
+        )
         assert empty_point_rdd.boundaryEnvelope == spatial_rdd.boundaryEnvelope
 
-        assert empty_point_rdd.rawSpatialRDD.map(lambda x: x.geom.area).collect()[0] == 0.0
-        assert empty_point_rdd.rawSpatialRDD.take(9)[4].getUserData() == "testattribute0\ttestattribute1\ttestattribute2"
+        assert (
+            empty_point_rdd.rawSpatialRDD.map(lambda x: x.geom.area).collect()[0] == 0.0
+        )
+        assert (
+            empty_point_rdd.rawSpatialRDD.take(9)[4].getUserData()
+            == "testattribute0\ttestattribute1\ttestattribute2"
+        )
 
     def test_raw_circle_rdd_assignment(self):
         point_rdd = PointRDD(
-            self.sc,
-            input_location,
-            offset,
-            splitter,
-            True,
-            num_partitions
+            self.sc, input_location, offset, splitter, True, num_partitions
         )
         circle_rdd = CircleRDD(point_rdd, 1.0)
         circle_rdd.analyze()
@@ -58,5 +62,7 @@ class TestSpatialRddAssignment(TestBase):
         circle_rdd_2.rawSpatialRDD = circle_rdd.rawSpatialRDD
         circle_rdd_2.analyze()
 
-        assert circle_rdd_2.countWithoutDuplicates() == circle_rdd.countWithoutDuplicates()
+        assert (
+            circle_rdd_2.countWithoutDuplicates() == circle_rdd.countWithoutDuplicates()
+        )
         assert circle_rdd_2.boundaryEnvelope == circle_rdd.boundaryEnvelope
