@@ -15,32 +15,33 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from sedona.core.SpatialRDD import PointRDD, PolygonRDD, CircleRDD
-from sedona.core.enums import GridType
-from sedona.core.geom.circle import Circle
-from sedona.core.spatialOperator import RangeQuery, KNNQuery, JoinQuery
 from tests.properties.crs_transform import *
 from tests.properties.polygon_properties import grid_type
 from tests.test_base import TestBase
 from tests.tools import distance_sorting_functions
 
+from sedona.core.enums import GridType
+from sedona.core.geom.circle import Circle
+from sedona.core.spatialOperator import JoinQuery, KNNQuery, RangeQuery
+from sedona.core.SpatialRDD import CircleRDD, PointRDD, PolygonRDD
+
 
 class TestCrsTransformation(TestBase):
 
     def test_spatial_range_query(self):
-        spatial_rdd = PointRDD(
-            self.sc,
-            input_location,
-            offset,
-            splitter,
-            True
-        )
+        spatial_rdd = PointRDD(self.sc, input_location, offset, splitter, True)
         spatial_rdd.flipCoordinates()
         spatial_rdd.CRSTransform("epsg:4326", "epsg:3005")
 
         for i in range(loop_times):
-            result_size = RangeQuery.SpatialRangeQuery(spatial_rdd, query_envelope, False, False).count()
+            result_size = RangeQuery.SpatialRangeQuery(
+                spatial_rdd, query_envelope, False, False
+            ).count()
             assert result_size == 3127
 
-        assert RangeQuery.SpatialRangeQuery(
-            spatial_rdd, query_envelope, False, False).take(10)[1].getUserData() is not None
+        assert (
+            RangeQuery.SpatialRangeQuery(spatial_rdd, query_envelope, False, False)
+            .take(10)[1]
+            .getUserData()
+            is not None
+        )
