@@ -23,7 +23,7 @@ import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions.{Expression, ImplicitCastInputTypes}
 import org.apache.spark.sql.catalyst.expressions.codegen.CodegenFallback
 import org.apache.spark.sql.catalyst.util.ArrayData
-import org.apache.spark.sql.sedona_sql.UDT.GeometryUDT
+import org.apache.spark.sql.sedona_sql.UDT.{GeometryUDT, GeographyUDT}
 import org.apache.spark.sql.types.{AbstractDataType, BinaryType, BooleanType, DataType, DataTypes, DoubleType, IntegerType, LongType, StringType}
 import org.apache.spark.unsafe.types.UTF8String
 import org.locationtech.jts.geom.Geometry
@@ -34,6 +34,7 @@ import scala.collection.mutable.ArrayBuffer
 import scala.reflect.runtime.universe.TypeTag
 import scala.reflect.runtime.universe.Type
 import scala.reflect.runtime.universe.typeOf
+import org.apache.sedona.common.geometryObjects.Geography
 
 /**
  * Custom exception to include the input row and the original exception message.
@@ -61,15 +62,16 @@ abstract class InferredExpression(fSeq: InferrableFunction*)
   lazy val f: InferrableFunction = fSeq match {
     // If there is only one function, simply use it and let org.apache.sedona.sql.UDF.Catalog handle default arguments.
     case Seq(f) => f
-    // If there are multiple overloaded functions, find the one with the same number of arguments as the input
-    // expressions. Please note that the Catalog won't be able to handle default arguments in this case. We'll
-    // move default argument handling from Catalog to this class in the future.
+    // If there are multiple overloaded functions, resolve the called function by comparing the types of input
+    // arguments with the types of function parameters.
     case _ =>
-      fSeq.find(f => f.sparkInputTypes.size == inputExpressions.size) match {
-        case Some(f) => f
-        case None =>
+      try {
+        FunctionResolver.resolveFunction(inputExpressions, fSeq)
+      } catch {
+        case e: IllegalArgumentException =>
           throw new IllegalArgumentException(
-            s"No overloaded function ${getClass.getName} has ${inputExpressions.size} arguments")
+            s"Cannot resolve function ${getClass.getName} with input arguments: " +
+              inputExpressions.map(_.dataType).mkString(", ") + s": ${e.getMessage}")
       }
   }
 
@@ -160,6 +162,10 @@ object InferrableType {
     new InferrableType[Geometry] {}
   implicit val geometryArrayInstance: InferrableType[Array[Geometry]] =
     new InferrableType[Array[Geometry]] {}
+  implicit val geographyInstance: InferrableType[Geography] =
+    new InferrableType[Geography] {}
+  implicit val geographyArrayInstance: InferrableType[Array[Geography]] =
+    new InferrableType[Array[Geography]] {}
   implicit val javaDoubleInstance: InferrableType[java.lang.Double] =
     new InferrableType[java.lang.Double] {}
   implicit val javaIntegerInstance: InferrableType[java.lang.Integer] =
@@ -200,6 +206,8 @@ object InferredTypes {
   def buildArgumentExtractor(t: Type): Expression => InternalRow => Any = {
     if (t =:= typeOf[Geometry]) { expr => input =>
       expr.toGeometry(input)
+    } else if (t =:= typeOf[Geography]) { expr => input =>
+      expr.toGeography(input)
     } else if (t =:= typeOf[Array[Geometry]]) { expr => input =>
       expr.toGeometryArray(input)
     } else if (InferredRasterExpression.isRasterType(t)) {
@@ -230,6 +238,12 @@ object InferredTypes {
       } else {
         null
       }
+    } else if (t =:= typeOf[Geography]) { output =>
+      if (output != null) {
+        output.asInstanceOf[Geography].toGenericArrayData
+      } else {
+        null
+      }
     } else if (InferredRasterExpression.isRasterType(t)) {
       InferredRasterExpression.rasterSerializer
     } else if (t =:= typeOf[String]) { output =>
@@ -259,6 +273,14 @@ object InferredTypes {
         } else {
           null
         }
+    } else if (t =:= typeOf[Array[Geography]] || t =:= typeOf[java.util.List[Geography]]) {
+      output =>
+        if (output != null) {
+          ArrayData.toArrayData(output.asInstanceOf[Array[Geography]].map(_.toGenericArrayData))
+        } else {
+          null
+        }
+
     } else if (InferredRasterExpression.isRasterArrayType(t)) {
       InferredRasterExpression.rasterArraySerializer
     } else if (t =:= typeOf[Option[Boolean]]) { output =>
@@ -277,6 +299,10 @@ object InferredTypes {
       GeometryUDT
     } else if (t =:= typeOf[Array[Geometry]] || t =:= typeOf[java.util.List[Geometry]]) {
       DataTypes.createArrayType(GeometryUDT)
+    } else if (t =:= typeOf[Geography]) {
+      GeographyUDT
+    } else if (t =:= typeOf[Array[Geography]] || t =:= typeOf[java.util.List[Geography]]) {
+      DataTypes.createArrayType(GeographyUDT)
     } else if (InferredRasterExpression.isRasterType(t)) {
       InferredRasterExpression.rasterUDT
     } else if (InferredRasterExpression.isRasterArrayType(t)) {
