@@ -582,10 +582,21 @@ class JoinQueryDetector(sparkSession: SparkSession) extends Strategy {
       return Nil
     }
 
+    // validate the k value
+    val kValue: Int = distance.eval().asInstanceOf[Int]
+    require(kValue >= 1, "The number of neighbors (k) must be equal or greater than 1.")
+
     val leftShape = children.head
     val rightShape = children.tail.head
 
-    val querySide = getKNNQuerySide(left, leftShape)
+    val querySide = matchExpressionsToPlans(leftShape, rightShape, left, right) match {
+      case Some((_, _, false)) =>
+        LeftSide
+      case Some((_, _, true)) =>
+        RightSide
+      case None =>
+        Nil
+    }
     val objectSidePlan = if (querySide == LeftSide) right else left
 
     checkObjectPlanFilterPushdown(objectSidePlan)
@@ -711,10 +722,21 @@ class JoinQueryDetector(sparkSession: SparkSession) extends Strategy {
 
     if (spatialPredicate == SpatialPredicate.KNN) {
       {
+        // validate the k value for KNN join
+        val kValue: Int = distance.get.eval().asInstanceOf[Int]
+        require(kValue >= 1, "The number of neighbors (k) must be equal or greater than 1.")
+
         val leftShape = children.head
         val rightShape = children.tail.head
 
-        val querySide = getKNNQuerySide(left, leftShape)
+        val querySide = matchExpressionsToPlans(leftShape, rightShape, left, right) match {
+          case Some((_, _, false)) =>
+            LeftSide
+          case Some((_, _, true)) =>
+            RightSide
+          case None =>
+            Nil
+        }
         val objectSidePlan = if (querySide == LeftSide) right else left
 
         checkObjectPlanFilterPushdown(objectSidePlan)
@@ -731,7 +753,7 @@ class JoinQueryDetector(sparkSession: SparkSession) extends Strategy {
             k = distance.get,
             useApproximate = false,
             spatialPredicate,
-            isGeography = false,
+            isGeography,
             condition = null,
             extraCondition = None) :: Nil
         } else {
@@ -746,7 +768,7 @@ class JoinQueryDetector(sparkSession: SparkSession) extends Strategy {
             k = distance.get,
             useApproximate = false,
             spatialPredicate,
-            isGeography = false,
+            isGeography,
             condition = null,
             extraCondition = None) :: Nil
         }
@@ -857,27 +879,6 @@ class JoinQueryDetector(sparkSession: SparkSession) extends Strategy {
     }
   }
 
-  /**
-   * Gets the query and object plans based on the left shape.
-   *
-   * This method checks if the left shape is part of the left or right plan and returns the query
-   * and object plans accordingly.
-   *
-   * @param leftShape
-   *   The left shape expression.
-   * @return
-   *   The join side where the left shape is located.
-   */
-  private def getKNNQuerySide(left: LogicalPlan, leftShape: Expression) = {
-    val isLeftQuerySide =
-      left.toString().toLowerCase().contains(leftShape.toString().toLowerCase())
-    if (isLeftQuerySide) {
-      LeftSide
-    } else {
-      RightSide
-    }
-  }
-
   /**
    * Check if the given condition is an equi-join between the given plans. This method basically
    * replicates the logic of
