@@ -19,6 +19,7 @@
 package org.apache.spark.sql.sedona_sql.strategy.join
 
 import org.apache.sedona.core.enums.IndexType
+import org.apache.sedona.core.spatialRddTool.IndexBuilder
 
 import scala.jdk.CollectionConverters._
 import org.apache.spark.broadcast.Broadcast
@@ -28,15 +29,18 @@ import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions.{Attribute, BindReferences, Expression, UnsafeRow}
 import org.apache.spark.sql.execution.SparkPlan
 import org.apache.spark.sql.sedona_sql.execution.SedonaUnaryExecNode
+import org.locationtech.jts.geom.Geometry
 
+import java.util.Collections
 
-case class SpatialIndexExec(child: SparkPlan,
-                            shape: Expression,
-                            indexType: IndexType,
-                            isRasterPredicate: Boolean,
-                            isGeography: Boolean,
-                            distance: Option[Expression] = None)
-  extends SedonaUnaryExecNode
+case class SpatialIndexExec(
+    child: SparkPlan,
+    shape: Expression,
+    indexType: IndexType,
+    isRasterPredicate: Boolean,
+    isGeography: Boolean,
+    distance: Option[Expression] = None)
+    extends SedonaUnaryExecNode
     with TraitJoinQueryBase
     with Logging {
 
@@ -51,16 +55,30 @@ case class SpatialIndexExec(child: SparkPlan,
     val boundShape = BindReferences.bindReference(shape, child.output)
     val resultRaw = child.execute().asInstanceOf[RDD[UnsafeRow]].coalesce(1)
     val spatialRDD = distance match {
-      case Some(distanceExpression) => toExpandedEnvelopeRDD(resultRaw, boundShape, BindReferences.bindReference(distanceExpression, child.output), isGeography)
-      case None => if (isRasterPredicate) {
-        toWGS84EnvelopeRDD(resultRaw, boundShape)
-      } else {
-        toSpatialRDD(resultRaw, boundShape)
-      }
+      case Some(distanceExpression) =>
+        toExpandedEnvelopeRDD(
+          resultRaw,
+          boundShape,
+          BindReferences.bindReference(distanceExpression, child.output),
+          isGeography)
+      case None =>
+        if (isRasterPredicate) {
+          toWGS84EnvelopeRDD(resultRaw, boundShape)
+        } else {
+          toSpatialRDD(resultRaw, boundShape)
+        }
     }
 
     spatialRDD.buildIndex(indexType, false)
-    sparkContext.broadcast(spatialRDD.indexedRawRDD.take(1).asScala.head).asInstanceOf[Broadcast[T]]
+    val spatialIndexes = spatialRDD.indexedRawRDD.take(1).asScala
+    val spatialIndex = if (spatialIndexes.nonEmpty) {
+      spatialIndexes.head
+    } else {
+      // The broadcasted dataframe contains 0 partition. In this case, we should provide an empty spatial index.
+      val indexBuilder = new IndexBuilder[Geometry](indexType)
+      indexBuilder.call(Collections.emptyIterator()).next()
+    }
+    sparkContext.broadcast(spatialIndex).asInstanceOf[Broadcast[T]]
   }
 
   protected def withNewChildInternal(newChild: SparkPlan): SparkPlan = {
