@@ -20,8 +20,6 @@ package org.apache.spark.sql.execution.datasources.parquet
 
 import org.apache.parquet.column.Dictionary
 import org.apache.parquet.io.api.{Binary, Converter, GroupConverter, PrimitiveConverter}
-import org.apache.parquet.schema.LogicalTypeAnnotation.TimeUnit
-import org.apache.parquet.schema.LogicalTypeAnnotation.TimestampLogicalTypeAnnotation
 import org.apache.parquet.schema.OriginalType.LIST
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName._
 import org.apache.parquet.schema.{GroupType, OriginalType, Type}
@@ -295,7 +293,7 @@ private[parquet] class GeoParquetRowConverter(
       case TimestampType if parquetType.getOriginalType == OriginalType.TIMESTAMP_MILLIS =>
         new ParquetPrimitiveConverter(updater) {
           override def addLong(value: Long): Unit = {
-            val micros = DateTimeUtils.millisToMicros(value)
+            val micros = GeoDateTimeUtils.millisToMicros(value)
             updater.setLong(timestampRebaseFunc(micros))
           }
         }
@@ -314,25 +312,6 @@ private[parquet] class GeoParquetRowConverter(
           }
         }
 
-      case TimestampNTZType
-          if canReadAsTimestampNTZ(parquetType) &&
-            parquetType.getLogicalTypeAnnotation
-              .asInstanceOf[TimestampLogicalTypeAnnotation]
-              .getUnit == TimeUnit.MICROS =>
-        new ParquetPrimitiveConverter(updater)
-
-      case TimestampNTZType
-          if canReadAsTimestampNTZ(parquetType) &&
-            parquetType.getLogicalTypeAnnotation
-              .asInstanceOf[TimestampLogicalTypeAnnotation]
-              .getUnit == TimeUnit.MILLIS =>
-        new ParquetPrimitiveConverter(updater) {
-          override def addLong(value: Long): Unit = {
-            val micros = DateTimeUtils.millisToMicros(value)
-            updater.setLong(micros)
-          }
-        }
-
       case DateType =>
         new ParquetPrimitiveConverter(updater) {
           override def addInt(value: Int): Unit = {
@@ -400,17 +379,6 @@ private[parquet] class GeoParquetRowConverter(
     }
   }
 
-  // Only INT64 column with Timestamp logical annotation `isAdjustedToUTC=false`
-  // can be read as Spark's TimestampNTZ type. This is to avoid mistakes in reading the timestamp
-  // values.
-  private def canReadAsTimestampNTZ(parquetType: Type): Boolean =
-    schemaConverter.isTimestampNTZEnabled() &&
-      parquetType.asPrimitiveType().getPrimitiveTypeName == INT64 &&
-      parquetType.getLogicalTypeAnnotation.isInstanceOf[TimestampLogicalTypeAnnotation] &&
-      !parquetType.getLogicalTypeAnnotation
-        .asInstanceOf[TimestampLogicalTypeAnnotation]
-        .isAdjustedToUTC
-
   /**
    * Parquet converter for strings. A dictionary is used to minimize string decoding cost.
    */
