@@ -31,14 +31,13 @@ import org.apache.spark.sql.SPARK_VERSION_METADATA_KEY
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions.SpecializedGetters
 import org.apache.spark.sql.catalyst.util.DateTimeUtils
-import org.apache.spark.sql.execution.datasources.DataSourceUtils
 import org.apache.spark.sql.execution.datasources.parquet.GeoParquetMetaData.{GEOPARQUET_COVERING_KEY, GEOPARQUET_CRS_KEY, GEOPARQUET_VERSION_KEY, VERSION, createCoveringColumnMetadata}
 import org.apache.spark.sql.execution.datasources.parquet.GeoParquetWriteSupport.GeometryColumnInfo
-import org.apache.spark.sql.internal.{LegacyBehaviorPolicy, SQLConf}
+import org.apache.spark.sql.internal.SQLConf
+import org.apache.spark.sql.internal.SQLConf.LegacyBehaviorPolicy
 import org.apache.spark.sql.sedona_sql.UDT.GeometryUDT
 import org.apache.spark.sql.types._
 import org.json4s.{DefaultFormats, Extraction, JValue}
-import org.json4s.jackson.compactJson
 import org.json4s.jackson.JsonMethods.parse
 import org.locationtech.jts.geom.Geometry
 import org.locationtech.jts.io.WKBWriter
@@ -88,20 +87,20 @@ class GeoParquetWriteSupport extends WriteSupport[InternalRow] with Logging {
   private val decimalBuffer =
     new Array[Byte](Decimal.minBytesForPrecision(DecimalType.MAX_PRECISION))
 
-  private val datetimeRebaseMode =
-    LegacyBehaviorPolicy.withName(SQLConf.get.getConf(SQLConf.PARQUET_REBASE_MODE_IN_WRITE))
+  private val datetimeRebaseMode = LegacyBehaviorPolicy.withName(
+    SQLConf.get.getConfString(GeoDataSourceUtils.PARQUET_REBASE_MODE_IN_WRITE))
 
   private val dateRebaseFunc =
-    DataSourceUtils.createDateRebaseFuncInWrite(datetimeRebaseMode, "Parquet")
+    GeoDataSourceUtils.creteDateRebaseFuncInWrite(datetimeRebaseMode, "Parquet")
 
   private val timestampRebaseFunc =
-    DataSourceUtils.createTimestampRebaseFuncInWrite(datetimeRebaseMode, "Parquet")
+    GeoDataSourceUtils.creteTimestampRebaseFuncInWrite(datetimeRebaseMode, "Parquet")
 
-  private val int96RebaseMode =
-    LegacyBehaviorPolicy.withName(SQLConf.get.getConf(SQLConf.PARQUET_INT96_REBASE_MODE_IN_WRITE))
+  private val int96RebaseMode = LegacyBehaviorPolicy.withName(
+    SQLConf.get.getConfString(GeoDataSourceUtils.PARQUET_INT96_REBASE_MODE_IN_WRITE))
 
   private val int96RebaseFunc =
-    DataSourceUtils.createTimestampRebaseFuncInWrite(int96RebaseMode, "Parquet INT96")
+    GeoDataSourceUtils.creteTimestampRebaseFuncInWrite(int96RebaseMode, "Parquet INT96")
 
   // A mapping from geometry field ordinal to bounding box. According to the geoparquet specification,
   // "Geometry columns MUST be at the root of the schema", so we don't need to worry about geometry
@@ -305,7 +304,7 @@ class GeoParquetWriteSupport extends WriteSupport[InternalRow] with Logging {
           case SQLConf.ParquetOutputTimestampType.TIMESTAMP_MILLIS =>
             (row: SpecializedGetters, ordinal: Int) =>
               val micros = row.getLong(ordinal)
-              val millis = DateTimeUtils.microsToMillis(timestampRebaseFunc(micros))
+              val millis = GeoDateTimeUtils.microsToMillis(timestampRebaseFunc(micros))
               recordConsumer.addLong(millis)
         }
 
